Attribute VB_Name = "db2evb"
'--------------------------------------------------------------------------------
'Source code shipped as samples
'
'Licensed Materials - Property of IBM
'
'5724- A91
'
'(C) Copyright IBM Corp. 1999, 2001, 2002.  All Rights Reserved.
'
'US Government Users Restricted Rights - Use, duplication or
'disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
'--------------------------------------------------------------------------------
'--------------------------------------------------------------------------------
' File: DB2evb.bas
'
' Description: Program illustrates how DB2 Everyplace can be used with
'              Visual Basic programs. This program has been tested to work
'
' Created: July 27, 2001
' Modified for AF on : July, 15 2002
'
' Version: 8.1
'
'--------------------------------------------------------------------------------

Option Explicit

Public henv    As Long          ' Environment handle
Public hdbc    As Long          ' Database handle
Public hstmt   As Long          ' Statement handle
Public rc      As Integer       ' Return code

Public dbpath As String        ' filesystem path where DB2e will create tables.
Public userid As String        ' Userid: not used by DB2 Everyplace.
Public pass   As String        ' Password: not used by DB2 Everyplace
Public DB2e   As AFDB2eLib.CAFDB2e




'--------------------------------------------------------------------------------
' Function: DB2eTest
'
' Description: Function illustrating how calls to DB2 Everyplace can be made.
'
'--------------------------------------------------------------------------------

Public Function DB2eTest() As Integer
    Dim errmsg As String
    Dim numCols As Integer
    Dim i As Integer
    Dim retLen As Long
    Dim data As String
    Dim drpStmt As String
    Dim crtStmt As String
    Dim insStmt1 As String
    Dim insStmt2 As String
    Dim selStmt As String
    On Error Resume Next
    
    
    Set DB2e = New AFDB2eLib.CAFDB2e
    
    
    dbpath = ""
    userid = ""
    pass = ""
    '
    drpStmt = "DROP TABLE x"
    crtStmt = "CREATE TABLE x(a INT, b TIMESTAMP)"
    insStmt1 = "INSERT INTO x VALUES(1, CURRENT TIMESTAMP)"
    insStmt2 = "INSERT INTO x VALUES(2, CURRENT TIMESTAMP)"
    selStmt = "SELECT * FROM x"
    '
    data = String(80, " ")
    '
    ' Step 1: allocate an environment handle.
    '
    DB2eForm.DB2eText.Text = vbCrLf & vbCrLf & " Allocating an environment handle"
    rc = DB2e.SQLAllocHandle(SQL_HANDLE_ENV, SQL_NULL_HENV, henv)
    If (rc <> 0) Then
        MsgBox ("Connection Failed at Env Handle")
        rc = DB2eTerminate()
        Exit Function
    End If
   
    '
    ' Step 2: allocate database handle
    '
    
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  Allocating a database handle"
    rc = DB2e.SQLAllocHandle(SQL_HANDLE_DBC, henv, hdbc)
    If (rc <> 0) Then
        MsgBox ("Connection Failed at DB Handle")
        rc = DB2eTerminate()
        Exit Function
    End If
                
    '
    ' Step 3: connect to the database
    '
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  Connecting to the database"
    rc = DB2e.SQLConnect(hdbc, dbpath, SQL_NTS, userid, SQL_NTS, pass, SQL_NTS)
    If (rc <> 0) Then
        MsgBox ("Connection Failed at SQLConnect")
        rc = DB2eTerminate()
        Exit Function
    End If
    
    
    '
    ' Step 4: allocate a statment handle.
    '
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  Allocating a statement handle"
    rc = DB2e.SQLAllocHandle(SQL_HANDLE_STMT, hdbc, hstmt)
    If (rc <> 0) Then
        MsgBox ("Connection Failed at STMT Handle")
        rc = DB2eTerminate()
        Exit Function
    End If

    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf
    
    '
    ' Now we can use CLI function calls to execute SQL statements.
    '
    ' Step 5: Drop a table
    '
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  " & drpStmt
    rc = DB2e.SQLExecDirect(hstmt, drpStmt, SQL_NTS)
    
    '
    ' Now we can use CLI function calls to execute SQL statements.
    '
    ' Step 6: Create a table
    '
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  " & crtStmt
    rc = DB2e.SQLExecDirect(hstmt, crtStmt, SQL_NTS)
    If (rc <> 0) Then
        rc = DB2eError()
        rc = DB2eTerminate()
        Exit Function
    End If
    
    
    '
    ' Step 7: Insert data into the table.
    '
    
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  " & insStmt1
    rc = DB2e.SQLExecDirect(hstmt, insStmt1, SQL_NTS)
    If (rc <> 0) Then
        rc = DB2eError()
        rc = DB2eTerminate()
        Exit Function

    End If

    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  " & insStmt2
    rc = DB2e.SQLExecDirect(hstmt, insStmt2, SQL_NTS)
    If (rc <> 0) Then
        rc = DB2eError()
        rc = DB2eTerminate()
        Exit Function

    End If
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf

    '
    ' Step 8: Retrieve data from table.
    '
    
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  " & selStmt & vbCrLf
    
    rc = DB2e.SQLExecDirect(hstmt, selStmt, SQL_NTS)
    If (rc <> 0) Then
        rc = DB2eError()
        rc = DB2eTerminate()
        Exit Function
    End If
    
    
    rc = DB2e.SQLNumResultCols(hstmt, numCols)
    If (rc <> 0) Then
        rc = DB2eError()
        rc = DB2eTerminate()
        Exit Function
    End If
    
    
    Do While (DB2e.SQLFetch(hstmt) = SQL_SUCCESS)
        For i = 1 To numCols
            rc = DB2e.SQLGetData(hstmt, i, SQL_C_CHAR, data, 80, retLen)
            DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & "  " & data & vbCrLf
            If (rc <> 0) Then
                rc = DB2eError()
                rc = DB2eTerminate()
                Exit Function
            End If
        Next
        data = String(80, " ")
        DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf
    Loop
    
    '
    ' Step 9: Close connection to DB2e database before application terminates.
    '
    rc = DB2eTerminate()
    MsgBox ("This is end")
    DB2eTest = 0
End Function

'--------------------------------------------------------------------------------
' Function: DB2eTerminate
'
' Description: Before terminating the application, make sure to disconnect properly from
'              DB2 Everyplace database.
'
'--------------------------------------------------------------------------------
Public Function DB2eTerminate() As Integer
    On Error Resume Next
    
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  Test complete, closing connection" & vbCrLf
    rc = DB2e.SQLDisconnect(hdbc)
    rc = DB2e.SQLFreeHandle(SQL_HANDLE_STMT, hstmt)
    rc = DB2e.SQLFreeHandle(SQL_HANDLE_DBC, hdbc)
    rc = DB2e.SQLFreeHandle(SQL_HANDLE_ENV, henv)
    DB2eTerminate = 0
End Function

'--------------------------------------------------------------------------------
' Function: DB2eError
'
' Description: Function to get error codes in case of error.
'
'--------------------------------------------------------------------------------

Public Function DB2eError() As Integer
    ' For use in DB2eError() :
    Dim sqlState As String
    Dim errorMsg As String
    Dim msgLen   As Integer
    Dim nativeError As Long
    On Error Resume Next
    
    sqlState = String(6, " ")
    errorMsg = String(80, " ")
    rc = DB2e.SQLGetDiagRec(SQL_HANDLE_STMT, hstmt, 1, sqlState, nativeError, errorMsg, 80, msgLen)
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  Error: sqlstate = " & sqlState & vbCrLf & " errorMsg - " & errorMsg
    DB2eError = 0
End Function





'--------------------------------------------------------------------------------
' Function: DB2eCreateRecord
'
' Description: Function illustrating how calls to DB2 Everyplace can be made.
'
'--------------------------------------------------------------------------------

Public Function DB2eRecord() As Integer
    Dim errmsg As String
    Dim numCols As Integer
    Dim i As Integer
    Dim retLen As Long
    Dim data As String
    Dim drpStmt As String
    Dim crtStmt As String
    Dim insStmt As String
    Dim insStmt1 As String
    Dim insStmt2 As String
    Dim selStmt As String
    On Error Resume Next
    Dim colLength As Long
    
    
    Set DB2e = New AFDB2eLib.CAFDB2e
    dbpath = ""
    userid = ""
    pass = ""
    '
    insStmt = "INSERT INTO x VALUES(?, ?)"
    selStmt = "SELECT * FROM x"
    '
    data = String(80, " ")
    '
    ' Step 1: allocate an environment handle.
    '
    DB2eForm.DB2eText.Text = vbCrLf & vbCrLf & " Allocating an environment handle"
    rc = DB2e.SQLAllocHandle(SQL_HANDLE_ENV, SQL_NULL_HENV, henv)
    If (rc <> 0) Then
        MsgBox ("Connection Failed")
        rc = DB2eTerminate()
        Exit Function
    End If
   
    '
    ' Step 2: allocate database handle
    '
    
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  Allocating a database handle"
    rc = DB2e.SQLAllocHandle(SQL_HANDLE_DBC, henv, hdbc)
    If (rc <> 0) Then
        MsgBox ("Connection Failed")
        rc = DB2eTerminate()
        Exit Function
    End If
                
    '
    ' Step 3: connect to the database
    '
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  Connecting to the database"
    rc = DB2e.SQLConnect(hdbc, dbpath, SQL_NTS, userid, SQL_NTS, pass, SQL_NTS)
    If (rc <> 0) Then
        MsgBox ("Connection Failed")
        rc = DB2eTerminate()
        Exit Function
    End If
    
    
    '
    ' Step 4: allocate a statment handle.
    '
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  Allocating a statement handle"
    rc = DB2e.SQLAllocHandle(SQL_HANDLE_STMT, hdbc, hstmt)
    If (rc <> 0) Then
        MsgBox ("Connection Failed")
        rc = DB2eTerminate()
        Exit Function
    End If
    
    
    '
    ' Step 5: prepare sql sqlstatement.
    '
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  Prepare Sql statement"
    rc = DB2e.SQLPrepare(hstmt, insStmt, SQL_NTS)
    If (rc <> 0) Then
        rc = DB2eError()
        rc = DB2eTerminate()
        Exit Function
    End If
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf
    
    '
    ' Step 6: bind parameter.
    '
    Dim col1Value As String
    col1Value = DB2eForm.txtField1.Text
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  BindParameter"
    rc = DB2e.SQLBindParameter(hstmt, 1, SQL_PARAM_INPUT, SQL_C_CHAR, SQL_INTEGER, 0, 0, col1Value, Len(col1Value) + 1, 0)
    If (rc <> 0) Then
        rc = DB2eError()
        rc = DB2eTerminate()
        Exit Function
    End If
    
    Dim col2Value As String
    col2Value = DB2eForm.txtField2.Text
    rc = DB2e.SQLBindParameter(hstmt, 2, SQL_PARAM_INPUT, SQL_C_CHAR, SQL_TYPE_TIMESTAMP, 0, 0, col2Value, Len(col2Value) + 1, 0)
    If (rc <> 0) Then
        rc = DB2eError()
        rc = DB2eTerminate()
        Exit Function
    End If


    '
    ' Step 7: execute the sql statement.
    '
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  Execute"
    rc = DB2e.SQLExecute(hstmt)
    If (rc <> 0) Then
        rc = DB2eError()
        rc = DB2eTerminate()
        Exit Function
    End If
    

    '
    ' Step 8: Retrieve data from table.
    '
    
    DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf & "  " & selStmt & vbCrLf
    rc = DB2e.SQLExecDirect(hstmt, selStmt, SQL_NTS)
    If (rc <> 0) Then
        rc = DB2eError()
        rc = DB2eTerminate()
        Exit Function
    End If
    
    
    rc = DB2e.SQLNumResultCols(hstmt, numCols)
    If (rc <> 0) Then
        rc = DB2eError()
        rc = DB2eTerminate()
        Exit Function
    End If
    
    
    Do While (DB2e.SQLFetch(hstmt) = SQL_SUCCESS)
        For i = 1 To numCols
            rc = DB2e.SQLGetData(hstmt, i, SQL_C_CHAR, data, 80, retLen)
            DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & "  " & data & vbCrLf
            If (rc <> 0) Then
                rc = DB2eError()
                rc = DB2eTerminate()
                Exit Function
            End If
        Next
        data = String(80, " ")
        DB2eForm.DB2eText.Text = DB2eForm.DB2eText.Text & vbCrLf
    Loop
    
    '
    ' Step 9: Close connection to DB2e database before application terminates.
    '
    rc = DB2eTerminate()
    MsgBox ("This is end")
End Function


